@@ -3,8 +3,10 @@ ra_function.ra_blocked <-
     block_ra(
       blocks = this[["blocks"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       prob_each = this[["prob_each"]],
       m = this[["m"]],
+      m_unit = this[["m_unit"]],
       block_m = this[["block_m"]],
       block_m_each = this[["block_m_each"]],
       block_prob = this[["block_prob"]],
@@ -19,8 +21,10 @@ ra_function.ra_blocked_and_clustered <-
       blocks = this[["blocks"]],
       clusters = this[["clusters"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       prob_each = this[["prob_each"]],
       m = this[["m"]],
+      m_unit = this[["m_unit"]],
       block_m = this[["block_m"]],
       block_m_each = this[["block_m_each"]],
       block_prob = this[["block_prob"]],
@@ -34,8 +38,10 @@ ra_function.ra_clustered <-
     cluster_ra(
       clusters = this[["clusters"]],
       m = this[["m"]],
+      m_unit = this[["m_unit"]],
       m_each = this[["m_each"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       prob_each = this[["prob_each"]],
       num_arms = this[["num_arms"]],
       conditions = this[["conditions"]],
@@ -47,8 +53,10 @@ ra_function.ra_complete <-
     complete_ra(
       N = this[["N"]],
       m = this[["m"]],
+      m_unit = this[["m_unit"]],
       m_each = this[["m_each"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       prob_each = this[["prob_each"]],
       num_arms = this[["num_arms"]],
       conditions = this[["conditions"]],
@@ -62,18 +70,22 @@ ra_function.ra_simple <-
     simple_ra(
       N = this[["N"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       prob_each = this[["prob_each"]],
       num_arms = this[["num_arms"]],
       conditions = this[["conditions"]],
-      check_inputs = this[["check_inputs"]]
+      check_inputs = this[["check_inputs"]],
+      simple = this[["simple"]]
     )
 ra_probabilities.ra_blocked <-
   function (this)
     block_ra_probabilities(
       blocks = this[["blocks"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       prob_each = this[["prob_each"]],
       m = this[["m"]],
+      m_unit = this[["m_unit"]],
       block_m = this[["block_m"]],
       block_m_each = this[["block_m_each"]],
       block_prob = this[["block_prob"]],
@@ -88,8 +100,10 @@ ra_probabilities.ra_blocked_and_clustered <-
       blocks = this[["blocks"]],
       clusters = this[["clusters"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       prob_each = this[["prob_each"]],
       m = this[["m"]],
+      m_unit = this[["m_unit"]],
       block_m = this[["block_m"]],
       block_m_each = this[["block_m_each"]],
       block_prob = this[["block_prob"]],
@@ -103,8 +117,10 @@ ra_probabilities.ra_clustered <-
     cluster_ra_probabilities(
       clusters = this[["clusters"]],
       m = this[["m"]],
+      m_unit = this[["m_unit"]],
       m_each = this[["m_each"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       prob_each = this[["prob_each"]],
       num_arms = this[["num_arms"]],
       conditions = this[["conditions"]],
@@ -116,8 +132,10 @@ ra_probabilities.ra_complete <-
     complete_ra_probabilities(
       N = this[["N"]],
       m = this[["m"]],
+      m_unit = this[["m_unit"]],
       m_each = this[["m_each"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       prob_each = this[["prob_each"]],
       num_arms = this[["num_arms"]],
       conditions = this[["conditions"]],
@@ -131,17 +149,21 @@ ra_probabilities.ra_simple <-
     simple_ra_probabilities(
       N = this[["N"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       prob_each = this[["prob_each"]],
       num_arms = this[["num_arms"]],
       conditions = this[["conditions"]],
-      check_inputs = this[["check_inputs"]]
+      check_inputs = this[["check_inputs"]],
+      simple = this[["simple"]]
     )
 rs_function.rs_clustered <-
   function (this)
     cluster_rs(
       clusters = this[["clusters"]],
       n = this[["n"]],
+      n_unit = this[["n_unit"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       simple = this[["simple"]],
       check_inputs = this[["check_inputs"]]
     )
@@ -150,20 +172,26 @@ rs_function.rs_complete <-
     complete_rs(
       N = this[["N"]],
       n = this[["n"]],
+      n_unit = this[["n_unit"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       check_inputs = this[["check_inputs"]]
     )
 rs_function.rs_simple <-
   function (this)
     simple_rs(N = this[["N"]],
               prob = this[["prob"]],
-              check_inputs = this[["check_inputs"]])
+              prob_unit = this[["prob_unit"]],
+              check_inputs = this[["check_inputs"]],
+              simple = this[["simple"]])
 rs_function.rs_stratified <-
   function (this)
     strata_rs(
       strata = this[["strata"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       n = this[["n"]],
+      n_unit = this[["n_unit"]],
       strata_n = this[["strata_n"]],
       strata_prob = this[["strata_prob"]],
       check_inputs = this[["check_inputs"]]
@@ -174,7 +202,9 @@ rs_function.rs_stratified_and_clustered <-
       strata = this[["strata"]],
       clusters = this[["clusters"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       n = this[["n"]],
+      n_unit = this[["n_unit"]],
       strata_n = this[["strata_n"]],
       strata_prob = this[["strata_prob"]],
       check_inputs = this[["check_inputs"]]
@@ -184,7 +214,9 @@ rs_probabilities.rs_clustered <-
     cluster_rs_probabilities(
       clusters = this[["clusters"]],
       n = this[["n"]],
+      n_unit = this[["n_unit"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       simple = this[["simple"]],
       check_inputs = this[["check_inputs"]]
     )
@@ -193,20 +225,26 @@ rs_probabilities.rs_complete <-
     complete_rs_probabilities(
       N = this[["N"]],
       n = this[["n"]],
+      n_unit = this[["n_unit"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       check_inputs = this[["check_inputs"]]
     )
 rs_probabilities.rs_simple <-
   function (this)
     simple_rs_probabilities(N = this[["N"]],
                             prob = this[["prob"]],
-                            check_inputs = this[["check_inputs"]])
+                            prob_unit = this[["prob_unit"]],
+                            check_inputs = this[["check_inputs"]],
+                            simple = this[["simple"]])
 rs_probabilities.rs_stratified <-
   function (this)
     strata_rs_probabilities(
       strata = this[["strata"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       n = this[["n"]],
+      n_unit = this[["n_unit"]],
       strata_n = this[["strata_n"]],
       strata_prob = this[["strata_prob"]],
       check_inputs = this[["check_inputs"]]
@@ -217,7 +255,9 @@ rs_probabilities.rs_stratified_and_clustered <-
       strata = this[["strata"]],
       clusters = this[["clusters"]],
       prob = this[["prob"]],
+      prob_unit = this[["prob_unit"]],
       n = this[["n"]],
+      n_unit = this[["n_unit"]],
       strata_n = this[["strata_n"]],
       strata_prob = this[["strata_prob"]],
       check_inputs = this[["check_inputs"]]
