@@ -6,11 +6,13 @@
 
 #'
 #' @param N The number of units. N must be a positive integer. (required)
-#' @param prob Use for a two-arm design. prob is the probability of assignment to treatment and must be a real number between 0 and 1 inclusive and must be length 1 or N. (optional)
+#' @param prob Use for a two-arm design. prob is the probability of assignment to treatment and must be a real number between 0 and 1 inclusive and must be length 1. (optional)
+#' @param prob_unit Use for a two-arm design. prob is the probability of assignment to treatment and must be a real number between 0 and 1 inclusive and must be length N. (optional)
 #' @param prob_each Use for a multi-arm design in which the values of prob_each determine the probabilities of assignment to each treatment condition. prob_each must be a numeric vector giving the probability of assignment to each condition. All entries must be nonnegative real numbers between 0 and 1 inclusive and the total must sum to 1. It may be a conditions-length vector or a N-by-conditions matrix.  (optional)
 #' @param num_arms The number of treatment arms. If unspecified, num_arms will be determined from the other arguments. (optional)
 #' @param conditions A character vector giving the names of the treatment groups. If unspecified, the treatment groups will be named 0 (for control) and 1 (for treatment) in a two-arm trial and T1, T2, T3, in a multi-arm trial. An exception is a two-group design in which num_arms is set to 2, in which case the condition names are T1 and T2, as in a multi-arm trial with two arms. (optional)
 #' @param check_inputs logical. Defaults to TRUE.
+#' @param simple logical. internal use only.
 #'
 #' @return A vector of length N that indicates the treatment condition of each unit. Is numeric in a two-arm trial and a factor variable (ordered by conditions) in a multi-arm trial.
 #' @export
@@ -43,15 +45,16 @@
 #' table(Z)
 simple_ra <- function(N,
                       prob = NULL,
+                      prob_unit = NULL,
                       prob_each = NULL,
                       num_arms = NULL,
                       conditions = NULL,
-                      check_inputs = TRUE) {
+                      check_inputs = TRUE,
+                      simple = TRUE) {
   if (check_inputs) {
     .invoke_check(check_randomizr_arguments_new)
   }
-  prob_mat <-
-    simple_ra_probabilities(N, prob, prob_each, num_arms, conditions, FALSE)
+  prob_mat <- simple_ra_probabilities(N, prob, prob_unit, prob_each, num_arms, conditions, FALSE)
   assignment <- conditions[vsample(prob_mat)]
   assignment <- clean_condition_names(assignment, conditions)
   return(assignment)
@@ -92,10 +95,12 @@ simple_ra <- function(N,
 simple_ra_probabilities <-
   function(N,
            prob = NULL,
+           prob_unit = NULL,
            prob_each = NULL,
            num_arms = NULL,
            conditions = NULL,
-           check_inputs = TRUE) {
+           check_inputs = TRUE, 
+           simple = TRUE) {
     if (check_inputs) .invoke_check(check_randomizr_arguments_new)
     
     # Three easy cases
@@ -104,8 +109,8 @@ simple_ra_probabilities <-
         t(prob_each)
       } else if (is.numeric(prob_each)) {
         prob_each
-      } else if (length(prob) > 1) {
-        rbind(1 - prob, prob)
+      } else if (is.numeric(prob_unit)) {
+        rbind(1 - prob_unit, prob_unit)
       } else if (is.numeric(prob)) {
         c(1 - prob, prob)
       } else{
